@@ -30,6 +30,7 @@ from .utils import obj2unicode
 from .utils import resolve_model
 from .utils import navinfo
 from .utils import Parametrizable
+from .utils import traverse_ddh_fklist
 from .requests import InstanceAction
 
 def discover_choosers():
@@ -91,7 +92,7 @@ def register_params(cls):
     instance).
 
     """
-    if cls.parameters:
+    if cls.parameters is not None:
         for k, v in cls.parameters.items():
             v.set_attributes_from_name(k)
             v.table = cls
@@ -102,11 +103,19 @@ def register_params(cls):
                 cls.parameters.keys())
         install_layout(cls, 'params_layout', cls._layout_class)
 
+    # e.g. ledger.ByJournal is just a mixin but provides a default value for its children
     elif cls.params_layout is not None:
         raise Exception(
             "{} has a params_layout but no parameters".format(
                 cls))
 
+    # if isinstance(cls, type) and cls.__name__.endswith("Users"):
+    # # if isinstance(cls, type) and cls.model is not None and cls.model.__name__ == "User":
+    #     # if str(cls.model) != "users.User":
+    #     #     raise Exception("{} {}".format(cls, cls.model))
+    #     print("20200825 {}.register_params {} {}".format(
+    #         cls, cls.parameters, cls.params_layout))
+
 
 def setup_params_choosers(self):
     if self.parameters:
@@ -340,50 +349,8 @@ class Action(Parametrizable, Permittable):
     """
 
     readonly = True
-    """
-    Whether this action is readonly, i.e. does not change any data in
-    the current data object.
-
-    Setting this to `False` will (1) disable the action for
-    `readonly` user types or when
-    :attr:`lino.core.site.Site.readonly` is True, and (2) will
-    cause it to be logged when :attr:`log_each_action_request
-    <lino.core.site.Site.log_each_action_request>` is set to
-    `True`.
-
-    Note that :class:`ShowInsert` is readonly because it does not
-    modify the current data object.  For example the button would
-    be disabled on a registered invoice.
-
-    Note that when a readonly action actually *does* modify the
-    object, Lino won't "notice" it.
-
-    Discussion
-
-    Maybe we should change the name `readonly` to `modifying` or
-    `writing` (and set the default value `False`).  Because for the
-    application developer that looks more natural.  Or --maybe better
-    but probably with even more consequences-- the default value
-    should be `False`.  Because being readonly, for actions, is a kind
-    of "privilege": they don't get logged, they also exists for
-    readonly users...  It would be more "secure" when the developer
-    must explicitly "say something" it when granting that privilege.
-
-    Another subtlety is the fact that this attribute is used by
-    :class:`lino.modlib.users.UserAuthored`.  For example the
-    :class:`StartTicketSession
-    <lino_xl.lib.working.StartTicketSession>` action in :ref:`noi` is
-    declared "readonly" because we want Workers who are not Triagers
-    to see this action even if they are not the author (reporter) of a
-    ticket.  In this use case the name should rather be
-    `requires_authorship`.
-    """
 
     opens_a_window = False
-    """
-    Whether this action opens a window.  If this is True, the user
-    interface is responsible for rendering that window.
-    """
 
     hide_top_toolbar = False
     """
@@ -806,9 +773,6 @@ class TableAction(Action):
 
 
 class ShowTable(TableAction):
-    """
-    Open a window with a grid editor on this table as main widget.
-    """
     use_param_panel = True
     show_in_workflow = False
     opens_a_window = True
@@ -817,13 +781,6 @@ class ShowTable(TableAction):
     select_rows = False
     callable_from = None
 
-    # def is_callable_from(self, caller):
-    #     return False
-
-    # def attach_to_actor(self, actor, name):
-    #     self.label = actor.label
-    #     return super(ShowTable, self).attach_to_actor(actor, name)
-
     def get_label(self):
         return self.label or self.defining_actor.label
 
@@ -889,11 +846,6 @@ class ShowEmptyTable(ShowDetail):
 
 
 class ShowInsert(TableAction):
-    """
-    Open the Insert window filled with a row of blank or default
-    values.  The new row will be actually created only when this
-    window gets submitted.
-    """
     save_action_name = 'submit_insert'
     show_in_plain = True
     disable_primary_key = False
@@ -944,7 +896,7 @@ class ShowInsert(TableAction):
 
     def get_view_permission(self, user_type):
         # the action is readonly because it doesn't write to the
-        # current object, but since it does modify the adtabase we
+        # current object, but since it does modify the database we
         # want to hide it for readonly users.
         if user_type and user_type.readonly:
             return False
@@ -1127,12 +1079,6 @@ class CreateRow(Action):
 
 
 class SubmitInsert(CreateRow):
-    """
-    Create a new database row using the data specified in the insert
-    window.  Called when the OK button of an Insert Window was
-    clicked.  Installed as `submit_insert` on every `dd.Model
-    <lino.core.model.Model>`.
-    """
     label = _("Create")
     action_name = None  # 'post'
     help_text = _("Create the record and open a detail window on it")
@@ -1284,6 +1230,29 @@ class DeleteSelected(MultipleRowAction):
                 ar.error(None, msg, alert=True)
                 return
 
+        # build a list of volatile related objects that will be deleted together
+        # with this one
+        cascaded_objects = {}
+        kernel = settings.SITE.kernel
+        for obj in ar.selected_rows:
+            for m, fk in traverse_ddh_fklist(obj.__class__):
+                # print(20200724, fk)
+                if fk.name in m.allow_cascaded_delete:
+                    qs = m.objects.filter(**{fk.name:obj})
+                    n = qs.count()
+                    if n:
+                        if m in cascaded_objects:
+                            cascaded_objects[m] += n
+                        else:
+                            cascaded_objects[m] = n
+
+            # print "20141208 generic related objects for %s:" % obj
+            for gfk, fk_field, qs in kernel.get_generic_related(obj):
+                if gfk.name in qs.model.allow_cascaded_delete:
+                    n = qs.count()
+                    if n:
+                        cascaded_objects[qs.model] = n
+
         def ok(ar2):
             super(DeleteSelected, self).run_from_ui(ar, **kw)
             # refresh_all must be True e.g. for when user deletes an item of a
@@ -1300,8 +1269,17 @@ class DeleteSelected(MultipleRowAction):
             d.update(type=ar.actor.model._meta.verbose_name)
         else:
             d.update(type=ar.actor.model._meta.verbose_name_plural)
-        msg = gettext("You are about to delete %(num)d %(type)s:\n%(targets)s") % d
-        ar.confirm(ok, "{}\n{}".format(msg, gettext("Are you sure ?")),
+            if len(objects) > 10:
+                objects = objects[:9] + ["..."]
+        msg = gettext("You are about to delete %(num)d %(type)s\n(%(targets)s)") % d
+
+        if len(cascaded_objects):
+            lst = ["{} {}".format(n, m._meta.verbose_name if n == 1 else m._meta.verbose_name_plural)
+                for m, n in cascaded_objects.items()]
+            msg += "\n" + gettext("as well as all related volatile records ({})").format(
+                ", ".join(lst))
+
+        ar.confirm(ok, "{}. {}".format(msg, gettext("Are you sure?")),
                    uid="deleting %(num)d %(type)s pks=" % d + "".join([str(t.pk) for t in ar.selected_rows]))
 
     def run_on_row(self, obj, ar):
