@@ -14,18 +14,20 @@ import logging; logger = logging.getLogger(__name__)
 
 import copy
 import traceback
+from types import GeneratorType
 
 from django.db import models
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
+from lino.utils import isiterable
 from lino.core import fields
 from lino.core import actions
 from lino.core import layouts
 from lino.core.requests import ActionRequest
 from lino.core.boundaction import BoundAction
 from lino.core.exceptions import ChangedAPI
-from lino.core.constants import _handle_attr_name
+from lino.core.constants import _handle_attr_name, CHOICES_BLANK_FILTER_VALUE
 from lino.core.permissions import add_requirements, Permittable
 from lino.core.utils import resolve_model
 from lino.core.utils import error2str
@@ -863,10 +865,11 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     @classmethod
     def summary_row(cls, ar, obj, **kw):
         """
-        Return a HTML representation of the given  data row `obj` for usage in a
+        Return a HTML representation of the given data row `obj` for usage in a
         summary panel.
 
-        See also :meth:`lino.core.model.Model.summary_row`.
+        The default implementation calls
+        :meth:`lino.core.model.Model.summary_row`.
 
         """
         return obj.summary_row(ar, **kw)
@@ -904,9 +907,10 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
             try:
                 settings.SITE.kernel.setup_handle(h, ar)
             except Exception as e:
-                traceback.print_exc()
-                logger.error("%s setup_handle failed with %s", self, e)
+                # traceback.print_exc()
+                logger.warning("%s setup_handle failed with %s", self, e)
                 delattr(self, hname)
+                # raise
 
         # logger.info("18072017, h:|%s|, h.store:|%s|, #1955"%(h, getattr(h,'store',None)))
         return h
@@ -934,12 +938,12 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
                 "{0} must convert `required` to `required_roles`".format(cls))
 
         master = getattr(cls, 'master', None)
-        if is_string(master):
+        if isinstance(master, str):
         # if isinstance(master, string_types):
             cls.master = resolve_model(master)
 
         model = getattr(cls, 'model', None)
-        if is_string(model):
+        if isinstance(model, str):
             model = cls.model = resolve_model(model)
 
         cls.collect_virtual_fields()
@@ -969,9 +973,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         actions.install_layout(cls, 'detail_layout', layouts.DetailLayout)
         actions.install_layout(cls, 'insert_layout', layouts.InsertLayout,
             window_size=(cls.insert_layout_width, 'auto'))
-        actions.install_layout(cls, 'card_layout', layouts.DetailLayout,
-            # window_size=(cls.card_layout_width, 'auto')
-        )
+        actions.install_layout(cls, 'card_layout', layouts.DetailLayout)
 
         if cls.abstract:
             return
@@ -987,27 +989,36 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
                 cls.parameters = params
 
         lst = []
-        for n in cls.get_simple_parameters():
-            if n in lst:
+        def append(n):
+            if isinstance(n, (GeneratorType, list, tuple)):
+                for i in n:
+                    append(i)
+            elif n in lst:
                 logger.warning(
                     "Removed duplicate name %s returned by %s.get_simple_parameters()", n, cls)
             else:
                 lst.append(n)
+        for n in cls.get_simple_parameters():
+            append(n)
         cls.simple_parameters = tuple(lst)
 
-        if cls.parameters is None and len(cls.simple_parameters) > 0 :
-            cls.parameters = {}
-
-        for name in cls.simple_parameters:
-            if name not in cls.parameters:
-                db_field = cls.get_data_elem(name)
-                if db_field is None:
-                    raise Exception("{}.get_simple_parameters() returned invalid name '{}'".format(cls, name))
-                cls.parameters[name] = dbfield2params_field(db_field)
-                # if "__" in name:
-                #     print("20200423", cls.parameters)
-        # if len(cls.parameters) == 0:
-        #     cls.parameters = None # backwards compatibility
+        if len(cls.simple_parameters) > 0:
+            if cls.parameters is None :
+                cls.parameters = {}
+            for name in cls.simple_parameters:
+                if name not in cls.parameters:
+                    db_field = cls.get_data_elem(name)
+                    if db_field is None:
+                        raise Exception("{}.get_simple_parameters() returned invalid name '{}'".format(cls, name))
+                    cls.parameters[name] = dbfield2params_field(db_field)
+                    # if "__" in name:
+                    #     print("20200423", cls.parameters)
+            if len(cls.parameters) == 0:
+                raise Exception("20200825")
+                # cls.parameters = None # backwards compatibility
+        # if cls.__name__.endswith("Users"):
+        #     print("20200825 {}.register_params {} {}".format(
+        #         cls, cls.parameters, cls.params_layout))
 
     @classmethod
     def collect_virtual_fields(cls):
@@ -1115,10 +1126,18 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
                 cls.submit_detail = cls._bind_action(
                     'submit_detail', actions.SubmitDetail())
 
+        # avoid inheriting the following actions from parent:
+        cls.insert_action = None
+        cls.delete_action = None
+        cls.update_action = None
+        cls.validate_form = None
+
         if cls.editable:
             if cls.allow_create:
                 # if cls.detail_action and not cls.hide_top_toolbar:
-                if cls.insert_layout and not cls.hide_top_toolbar:
+                # if cls.insert_layout and not cls.hide_top_toolbar:
+                # NB polls.AnswerRemarksByAnswer has hide_top_toolbar but we need its insert_action.
+                if cls.insert_layout:
                     cls.insert_action = cls._bind_action(
                         'insert_action', cls.get_insert_action())
             if not cls.hide_top_toolbar:
@@ -1321,7 +1340,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
                 yield t
         for k in self.simple_parameters:
             v = getattr(ar.param_values, k)
-            if v:
+            if v and v != CHOICES_BLANK_FILTER_VALUE:
                 yield str(self.parameters[k].verbose_name) + ' ' + str(v)
 
     @classmethod
@@ -1614,7 +1633,6 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 
         if not self.is_abstract():
             actions.register_params(self)
-
             self._collect_actions()
 
         if not self.is_abstract():
@@ -1859,19 +1877,21 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 
     @classmethod
     def get_table_summary(cls, obj, ar):
-        """Return the HTML paragraph to be displayed by
+        """Return the HTML `<div>` to be displayed by
         :class:`lino.core.elems.TableSummaryPanel`.  That is (1) in a
         detail form when :attr:`display_mode` is `summary` or (2)
         in a grid.
 
-        Lino internally creates a virtualfield ``slave_summary`` on
-        each table which invokes this method.
+        Lino internally creates a virtualfield ``slave_summary`` on each table
+        that invokes this method.
 
         """
         # ar = ar.spawn(self, master_instance=obj, is_on_main_actor=False)
-        sar = ar.spawn_request(actor=cls, master_instance=obj, is_on_main_actor=False)
-        # sar = cls.request_from(ar, master_instance=obj)
-        p = qs2summary(sar, sar.data_iterator, cls.summary_sep)
+        # sar = ar.spawn_request(actor=cls, master_instance=obj,
+        #     is_on_main_actor=False)
+        sar = cls.request_from(ar, master_instance=obj, is_on_main_actor=False)
+        p = E.div(*qs2summary(sar, sar.data_iterator, separator=cls.summary_sep,
+                max_items=cls.preview_limit))
         if cls.insert_action is not None:
             ir = cls.insert_action.request_from(sar)
             if ir.get_permission():
