@@ -41,33 +41,40 @@ class Choice(fields.TableRow):
     current language at runtime.  Every item of a :class:`ChoiceList`
     must be an instance of :class:`Choice` or a subclass thereof.
 
+    .. attribute:: choicelist
+
+        The choice list that owns this choice.
+
+    .. attribute:: value
+
+        (a string) The value to use e.g. when this choice is being stored in a
+        database.
+
+    .. attribute:: text
+
+        A translatable string containing the text to show to the user.
+
+    .. attribute:: names
+
+        A list of names to be used as attribute name on the choicelist for referring
+        to this choice from application code.
+
+        If this is `None` or not specified, the choice is a nameless
+        choice, which is a full-fledged choice object but is not
+        accessible as a class attribute on its choicelist.
+
+    .. attribute:: button_text
+
+        The text to appear on buttons representing this state.
+
     """
     choicelist = None
     remark = None
     pk = None
-
     value = None
-
-    """(a string) The value to use e.g. when this choice is being stored in a
-    database."""
-
     text = None
-    """A translatable string containing the text to show to the user.
-
-    """
-
     names = ''
-    """
-
-    A list of names to be used as attribute name on the choicelist for referring
-    to this choice from application code.
-
-    If this is `None` or not specified, the choice is a nameless
-    choice, which is a full-fledged choice object but is not
-    accessible as a class attribute on its choicelist.
-
-    """
-
+    button_text = None
 
     def __init__(self, value=None, text=None, names=None, **kwargs):
         """Create a new :class:`Choice` instance.
@@ -417,6 +424,8 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
     hidden_columns = frozenset(['workflow_buttons'])
 
     column_names = 'value name text *'
+    
+    button_text = models.CharField(_("Button text"), blank=True)
 
     old2new = {}
     """
@@ -642,7 +651,7 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
         nv = cls.old2new.get(value)
         if nv is not None:
             value = nv
-        v = cls.items_dict.get(value) or cls.get_by_name(value)
+        v = cls.items_dict.get(value) or cls.get_by_name(value, None)
         if v is not None:
             return v
         if settings.SITE.strict_choicelist_values:
@@ -663,7 +672,7 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
         #~ We must make it dynamic since e.g. UserTypes can change after
         #~ the fields have been created.
 
-        #~ https://docs.djangoproject.com/en/dev/ref/models/fields/
+        #~ https://docs.djangoproject.com/en/3.1/ref/models/fields/
         #~ note that choices can be any iterable object -- not necessarily
         #~ a list or tuple. This lets you construct choices dynamically.
         #~ But if you find yourself hacking choices to be dynamic, you're
@@ -871,7 +880,7 @@ class ChoiceListField(models.CharField):
     def deconstruct(self):
         """
         Needed for Django 1.7+, see
-        https://docs.djangoproject.com/en/dev/howto/custom-model-fields/#custom-field-deconstruct-method
+        https://docs.djangoproject.com/en/3.1/howto/custom-model-fields/#custom-field-deconstruct-method
         """
 
         name, path, args, kwargs = super(ChoiceListField, self).deconstruct()
