@@ -15,13 +15,16 @@ from django.conf import settings
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.core.exceptions import ValidationError
+from django.core.exceptions import FieldDoesNotExist
 from django.db.models.fields import NOT_PROVIDED
 from django.utils.functional import cached_property
 
 from lino.core.utils import resolve_field, full_model_name, resolve_model
 from lino.core.exceptions import ChangedAPI
 from lino.core.diff import ChangeWatcher
+from lino.core import constants
 
+from lino.utils import isiterable
 from lino.utils import get_class_attr
 from lino.utils import IncompleteDate
 from lino.utils import quantities
@@ -142,7 +145,7 @@ class MonthField(models.DateField):
 class PriceField(models.DecimalField):
     """
     A thin wrapper around Django's `DecimalField
-    <https://docs.djangoproject.com/en/1.11/ref/models/fields/#decimalfield>`_
+    <https://docs.djangoproject.com/en/3.1/ref/models/fields/#decimalfield>`_
     which adds default values for `decimal_places`, `max_length` and
     `max_digits`.
     """
@@ -430,7 +433,7 @@ class VirtualModel:
 VFIELD_ATTRIBS = frozenset('''to_python choices save_form_data
   value_to_string max_length remote_field
   max_digits verbose_name decimal_places
-  help_text blank'''.split())
+  blank'''.split())
 
 class VirtualField(FakeField):
     """
@@ -508,6 +511,10 @@ class VirtualField(FakeField):
         for k in VFIELD_ATTRIBS:
             setattr(self, k, getattr(f, k, None))
 
+        # copy help_text if it hasn't been set by help_texts_extractor
+        if f.help_text and not self.help_text:
+            self.help_text = f.help_text
+
         # if self.name == 'detail_pointer':
         #     logger.info('20170905 resolve_type 1 %s on %s',
         #                 self.name, self.verbose_name)
@@ -1159,19 +1166,6 @@ class TableRow(object):
             return a
 
     def get_choices_text(self, request, actor, field):
-        """
-        Return the text to be displayed when an instance of this model
-        is being used as a choice in a combobox of a ForeignKey field
-        pointing to this model.
-        `request` is the web request,
-        `actor` is the requesting actor.
-
-        The default behaviour is to simply return `str(self)`.
-
-        A usage example
-        is :class:`lino_xl.lib.countries.Place`.
-
-        """
         return str(self)
 
     def get_overview_elems(self, ar):
@@ -1255,10 +1249,10 @@ def fields_list(model, field_names):
         else:
             e = model.get_data_elem(name)
             if e is None:
-                raise models.FieldDoesNotExist(
+                raise FieldDoesNotExist(
                     "No data element %r in %s" % (name, model))
             if not hasattr(e, 'name'):
-                raise models.FieldDoesNotExist(
+                raise FieldDoesNotExist(
                     "%s %r in %s has no name" % (e.__class__, name, model))
             if isinstance(e, DummyField):
                 pass
@@ -1416,3 +1410,79 @@ def make_remote_field(model, name):
 #         ...
 #
 #
+
+def choices_for_field(ar, holder, field):
+    """
+    Return the choices for the given field and the given HTTP request
+    whose `holder` is either a Model, an Actor or an Action.
+    """
+    if not holder.get_view_permission(ar.request.user.user_type):
+        raise Exception(
+            "{user} has no permission for {holder}".format(
+                user=ar.request.user, holder=holder))
+    # model = holder.get_chooser_model()
+    chooser = holder.get_chooser_for_field(field.name)
+    # logger.info('20140822 choices_for_field(%s.%s) --> %s',
+    #             holder, field.name, chooser)
+    if chooser:
+        qs = chooser.get_request_choices(ar, holder)
+        if not isiterable(qs):
+            raise Exception("%s.%s_choices() returned non-iterable %r" % (
+                holder.model, field.name, qs))
+        if chooser.simple_values:
+            def row2dict(obj, d):
+                d[constants.CHOICES_TEXT_FIELD] = str(obj)
+                d[constants.CHOICES_VALUE_FIELD] = obj
+                return d
+        elif chooser.instance_values:
+            # same code as for ForeignKey
+            def row2dict(obj, d):
+                d[constants.CHOICES_TEXT_FIELD] = holder.get_choices_text(
+                    obj, ar.request, field)
+                d[constants.CHOICES_VALUE_FIELD] = obj.pk
+                return d
+        else:  # values are (value, text) tuples
+            def row2dict(obj, d):
+                d[constants.CHOICES_TEXT_FIELD] = str(obj[1])
+                d[constants.CHOICES_VALUE_FIELD] = obj[0]
+                return d
+        return (qs, row2dict)
+
+    if field.choices:
+        qs = field.choices
+
+        def row2dict(obj, d):
+            if type(obj) is list or type(obj) is tuple:
+                d[constants.CHOICES_TEXT_FIELD] = str(obj[1])
+                d[constants.CHOICES_VALUE_FIELD] = obj[0]
+            else:
+                d[constants.CHOICES_TEXT_FIELD] = holder.get_choices_text(
+                    obj, ar.request, field)
+                d[constants.CHOICES_VALUE_FIELD] = str(obj)
+            return d
+
+        return (qs, row2dict)
+
+    if isinstance(field, VirtualField):
+        field = field.return_type
+
+    if isinstance(field, RemoteField):
+        field = field.field
+        if isinstance(field, VirtualField):  # 20200425
+            field = field.return_type
+
+    if isinstance(field, models.ForeignKey):
+        m = field.remote_field.model
+        t = m.get_default_table()
+        qs = t.request(request=ar.request).data_iterator
+
+        # logger.info('20120710 choices_view(FK) %s --> %s', t, qs.query)
+
+        def row2dict(obj, d):
+            d[constants.CHOICES_TEXT_FIELD] = holder.get_choices_text(
+                obj, ar.request, field)
+            d[constants.CHOICES_VALUE_FIELD] = obj.pk
+            return d
+    else:
+        raise http.Http404("No choices for %s" % field)
+    return (qs, row2dict)
