@@ -2,7 +2,7 @@
 # Copyright 2009-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-"Defines the :class:`Model` class."
+"Defines the :class:`Model` class.  See :ref:`dev.models`."
 
 import logging ; logger = logging.getLogger(__name__)
 import copy
@@ -10,20 +10,25 @@ import copy
 from django.db import models
 from django.conf import settings
 from django.core.exceptions import ValidationError
+from django.core.exceptions import FieldDoesNotExist
 from django.utils.translation import ugettext_lazy as _
+from django.db.models.signals import pre_delete
+from django.utils.text import format_lazy
 
-from etgen.html import E, forcetext, tostring
+from etgen.html import E, forcetext, tostring, join_elems
 
 from lino.core import fields
 from lino.core import signals
 from lino.core import actions
-from .fields import make_remote_field, RichTextField
+
+
+from .fields import make_remote_field, RichTextField, displayfield
 from .utils import error2str
 from .utils import obj2str
 from .diff import ChangeWatcher
 from .utils import obj2unicode
 from .utils import class_dict_items
-from .signals import on_ui_created, pre_ui_delete, pre_ui_save
+from .signals import receiver, on_ui_created, pre_ui_delete, pre_ui_save
 from .workflows import ChangeStateAction
 
 try:
@@ -35,83 +40,13 @@ except ImportError:
 
 
 class Model(models.Model, fields.TableRow):
-    """Lino adds a series of features to Django's `Model
-    <https://docs.djangoproject.com/en/dev/ref/models/class/>`_
-    class.  If a Lino application includes plain Django Model
-    classes, Lino will "extend" these by adding the attributes and
-    methods defined here to these classes.
-
-    .. attribute:: workflow_buttons
-
-        A virtual field that displays the **workflow actions** for
-        this row.  This is a compact but intuitive representation of
-        the current workflow state, together with a series of
-        clickable actions.
-
-    .. attribute:: overview
-
-        A fragment of HTML describing this object in a customizable story of
-        paragraphs.
-
-        Customizable using :meth:`get_overview_elems`.
-
-    .. attribute:: detail_link
-
-        A virtual field which displays this database row as a clickable link
-        which opens the detail window.  Functionally equivalent to a double
-        click, but more intuitive in some places.
+    """
+    Lino's extension of the plain Django Model class.
 
     .. method:: full_clean
 
         This is defined by Django.
 
-    .. method:: FOO_changed
-
-        Called when field FOO of an instance of this model has been
-        modified through the user interface.
-
-        Example::
-
-          def city_changed(self, ar):
-              print("User {} changed city of {} to {}!".format(
-                  ar.get_user(), self, self.city))
-
-        Note: If you want to know the old value when reacting to a change,
-        consider writing :meth:`after_ui_save` instead.
-
-    .. method:: FOO_choices
-
-        Return a queryset or list of allowed choices for field FOO.
-
-        For every field named "FOO", if the model has a method called
-        "FOO_choices" (which must be decorated by :func:`dd.chooser`),
-        then this method will be installed as a chooser for this
-        field.
-
-        Example of a context-sensitive chooser method::
-
-          country = dd.ForeignKey(
-              'countries.Country', blank=True, null=True)
-          city = dd.ForeignKey(
-              'countries.City', blank=True, null=True)
-
-          @chooser()
-          def city_choices(cls,country):
-              if country is not None:
-                  return country.place_set.order_by('name')
-              return cls.city.field.remote_field.model.objects.order_by('name')
-
-
-    .. method:: create_FOO_choice
-
-        For every field named "FOO" for which a chooser exists, if the model
-        also has a method called "create_FOO_choice", then this chooser will be
-        a :term:`learning chooser`. That is, users can enter text into the
-        combobox, and Lino will create a new database object from it.
-
-        This works only if FOO is (1) a foreign key and (2) has a chooser.
-        See also :term:`learning foreign key`.
-
     """
 
     class Meta(object):
@@ -166,8 +101,11 @@ class Model(models.Model, fields.TableRow):
 
     grid_post = actions.CreateRow()
     submit_insert = actions.SubmitInsert()
-    """This is the action represented by the "Create" button of an Insert
-    window. See :mod:`lino.mixins.dupable` for an example of how to
+    """
+    The :class:`SubmitInsert <lino.core.actions.SubmitInsert>` action to be executed when the
+    when the users submits an insert window.
+
+    See :mod:`lino.mixins.dupable` for an example of how to
     override it.
 
     """
@@ -268,9 +206,9 @@ class Model(models.Model, fields.TableRow):
     Internally used by :meth:`watch_changes`
     """
 
-    disable_create_choice = False
-    """Whether to disable any automatic creation by learning choosers.
-    """
+    # disable_create_choice = False
+    # """Whether to disable any automatic creation by learning choosers.
+    # """
 
     summary_row_template = None
     """
@@ -322,8 +260,8 @@ class Model(models.Model, fields.TableRow):
                     #     "of same name.".format(
                     #         full_model_name(model), k, f.__class__.__name__))
                 if m is not model:
-                    # if k == "overview" and model.__name__ == "DailyPlannerRow":
-                    #     print("20181022", m, model)
+                    # if k == "municipality" and model.__name__ == "Client":
+                    #     print("20200818", m, model)
                     # settings.SITE.VIRTUAL_FIELDS.pop(v)
                     v = copy.deepcopy(v)
                 settings.SITE.register_virtual_field(v)
@@ -348,7 +286,7 @@ class Model(models.Model, fields.TableRow):
                 return rf
         try:
             return cls._meta.get_field(name)
-        except models.FieldDoesNotExist:
+        except FieldDoesNotExist:
             pass
 
         for vf in cls._meta.private_fields:
@@ -362,35 +300,6 @@ class Model(models.Model, fields.TableRow):
 
 
     def disable_delete(self, ar=None):
-        """
-        Decide whether this database object may be deleted.  Return `None`
-        if it is okay to delete this object, otherwise a nonempty
-        translatable string with a message that explains in user
-        language why this object cannot be deleted.
-
-        The argument `ar` contains the action request which is trying
-        to delete. `ar` is possibly `None` when this is being called
-        from a script or batch process.
-
-        The default behaviour checks whether there are any related
-        objects which would not get cascade-deleted and thus produce a
-        database integrity error.
-
-        You can override this method e.g. for defining additional
-        conditions.  Example::
-
-          def disable_delete(self, ar=None):
-              msg = super(MyModel, self).disable_delete(ar)
-              if msg is not None:
-                  return msg
-              if self.is_imported:
-                  return _("Cannot delete imported records.")
-
-        When overriding, be careful to not skip the `super` method.
-
-        Note that :class:`lino.mixins.polymorphic.Polymorphic`
-        overrides this.
-        """
         # In case of MTI, every concrete model has its own ddh.
         # Deleting an Invoice will also delete the Voucher. Ask all
         # MTI parents (other than self) whether they have a veto .
@@ -527,6 +436,32 @@ class Model(models.Model, fields.TableRow):
         if hasattr(cls, 'bleached_fields'):
             raise ChangedAPI("Replace bleached_fields by bleached=True on each field")
 
+    @classmethod
+    def create_from_choice(cls, text):
+        """
+        Called when a learning combo has been submitted.
+        Create a persistent database object if the given text contains enough information.
+        """
+        # if cls.disable_create_choice:
+        #     return
+        values = cls.choice_text_to_dict(text)
+        if values is None:
+            raise ValidationError(
+                _("Cannot create {obj} from '{text}'").format(
+                obj=cls._meta.verbose_name, text=text))
+        obj = cls(**values)
+        obj.full_clean()
+        obj.save()
+        return obj
+
+
+    @classmethod
+    def choice_text_to_dict(cls, text):
+        """
+        Return a dict of the fields to fill when the given text contains enough
+        information for creating a new database object.
+        """
+        return None
 
     @classmethod
     def lookup_or_create(model, lookup_field, value, **known_values):
@@ -619,12 +554,12 @@ class Model(models.Model, fields.TableRow):
         """
         pass
 
-    def before_ui_save(self, ar):
+    def before_ui_save(self, ar, cw):
         """A hook for adding custom code to be executed each time an
         instance of this model gets updated via the user interface and
         **before** the changes are written to the database.
 
-        Deprecated.  Use the :data:`pre_ui_save
+        Consider using the :data:`pre_ui_save
         <lino.core.signals.pre_ui_save>` signal instead.
 
         Example in :class:`lino_xl.lib.cal.Event` to mark the
@@ -698,7 +633,7 @@ class Model(models.Model, fields.TableRow):
     def save_new_instance(elem, ar):
         """Save this instance and fire related behaviour."""
         pre_ui_save.send(sender=elem.__class__, instance=elem, ar=ar)
-        elem.before_ui_save(ar)
+        elem.before_ui_save(ar, None)
         elem.save(force_insert=True)
         # yes, `on_ui_created` comes *after* save()
         on_ui_created.send(elem, request=ar.request)
@@ -711,7 +646,7 @@ class Model(models.Model, fields.TableRow):
     def save_watched_instance(elem, ar, watcher):
         if watcher.is_dirty():
             pre_ui_save.send(sender=elem.__class__, instance=elem, ar=ar)
-            elem.before_ui_save(ar)
+            elem.before_ui_save(ar, watcher)
             elem.save(force_update=True)
             watcher.send_update(ar)
             ar.success(_("%s has been updated.") % obj2unicode(elem))
@@ -880,15 +815,15 @@ class Model(models.Model, fields.TableRow):
 
             def summary_row(self, ar):
                 elems = [ar.obj2html(self)]
-                if self.city and not "city" in ar.known_values:
+                if self.city and not ar.is_obvious_field("city"):
                     elems += [" (", ar.obj2html(self.city), ")"]
-                return E.p(*elems)
+                return elems
 
         Note that this is called by the class method of same name on
-        :class:`lino.core.actors.Actor`, which can potentially be customized and
-        can potentially decide to not call the model method.
+        :class:`lino.core.actors.Actor`, which may be customized and may decide
+        to not call the model method.
 
-        TODO: rename this to `get_row_description` and write documentation.
+        TODO: rename this to `row2summary` and write documentation.
 
         """
         yield ar.obj2html(self)
@@ -914,8 +849,9 @@ class Model(models.Model, fields.TableRow):
             return ''
         return E.div(*forcetext(self.get_overview_elems(ar)))
 
-    @fields.displayfield(_("Workflow"))
+    @fields.displayfield(_("Workflow"), help_text="List of actions that change the workflow state of this object.")
     def workflow_buttons(self, ar):
+
         if ar is None:
             return ''
         return self.get_workflow_buttons(ar)
@@ -1110,6 +1046,64 @@ class Model(models.Model, fields.TableRow):
         """
         return []
 
+    @classmethod
+    def add_picker(model, fldname):
+        """Add a picker for the named choicelist field.
+
+        A picker is a virtual field that shows all the available choices in a
+        way that you can click on them to change the underlying choicelist
+        field's value.  Functionally similar to a radio button, but causes
+        immediate submit instead of waiting until the form gets submitted.
+
+        """
+        fld = model._meta.get_field(fldname)
+        cls = fld.choicelist
+        action_name = "do_pick_" + fldname
+        vfield_name = "pick_" + fldname
+
+        class QuickSetChoice(actions.Action):
+
+            label = cls.verbose_name
+            icon_name = None
+            show_in_bbar = False
+            no_params_window = True
+            parameters = dict(choice=cls.field())
+
+            def run_from_ui(self, ar, **kw):
+                obj = ar.selected_rows[0]
+                pv = ar.action_param_values
+                setattr(obj, fld.attname, pv.choice)
+                obj.full_clean()
+                obj.save()
+                ar.success(refresh=True)
+
+        ai = QuickSetChoice()
+        setattr(model, action_name, ai)
+
+        lbl = format_lazy(_("Pick {}"), cls.verbose_name)
+
+        @displayfield(lbl, editable=True)
+        def pick_choice(self, ar):
+            if ar is None:
+                return fld.value_from_object(self)
+            elems = []
+            ba = ar.actor.get_action_by_name(action_name)
+            for v in cls.get_list_items():
+                kw = dict(action_param_values=dict(choice=v))
+                label = str(v.button_text or v.text)
+                if fld.value_from_object(self) == v:
+                    elems.append(E.b(label))
+                else:
+                    if fldname in ar.actor.get_disabled_fields(self, ar):
+                        pass  # elems.append(label)
+                    else:
+                        elems.append(ar.action_button(
+                            ba, self, label=label, request_kwargs=kw))
+            return E.p(*join_elems(elems, sep=" | "))
+
+        setattr(model, vfield_name, pick_choice)
+
+
     @classmethod
     def django2lino(cls, model):
         """
@@ -1256,10 +1250,6 @@ LINO_MODEL_ATTRIBS = (
     'show_in_site_search', 'allow_merge_action')
 
 
-from lino.core.signals import receiver
-from django.db.models.signals import pre_delete
-
-
 @receiver(pre_delete)
 def pre_delete_handler(sender, instance=None, **kw):
     """Before actually deleting an object, we override Django's behaviour
