@@ -669,8 +669,7 @@ class TextRenderer(HtmlRenderer):
             recno += 1
             if show_links:
                 rows.append([
-                    to_rst(x) for x in ar.row2html(
-                        recno, fields, row, sums)])
+                    to_rst(x) for x in ar.row2html(recno, fields, row, sums)])
             else:
                 rows.append([x for x in ar.row2text(fields, row, sums)])
 
@@ -794,7 +793,7 @@ class JsRenderer(HtmlRenderer):
         either `data_record` or a `record_id`.
 
         Usually `data_record`, except if it is a `file upload
-        <https://docs.djangoproject.com/en/dev/topics/http/file-uploads/>`_
+        <https://docs.djangoproject.com/en/3.1/topics/http/file-uploads/>`_
         where some mysterious decoding problems (:blogref:`20120209`)
         force us to return a `record_id` which has the same visible
         result but using an additional GET.
@@ -891,6 +890,9 @@ class JsRenderer(HtmlRenderer):
         ba = obj.get_detail_action(ar)
         if ba is None:
             return None
+        if not ba.get_row_permission(ar, obj, None):
+            # fixes #3857
+            return None
         if ar.permalink_uris:
             return self.get_detail_url(ar, ba.actor, obj.pk)
         return self.js2url(self.instance_handler(ar, obj, None))
