@@ -265,7 +265,7 @@ class BaseRequest(object):
             for k in inheritable_attrs:
                 if k in kw:
                     if kw[k] is None:
-                        raise Exception("%s : %s=None" % (kw, k))
+                        raise Exception("%s : %s is None" % (kw, k))
                 else:
                     kw[k] = getattr(parent, k)
             kv = kw.setdefault('known_values', {})
@@ -1192,7 +1192,7 @@ class BaseRequest(object):
 
         if is_new or watcher.is_dirty():
             pre_ui_save.send(sender=elem.__class__, instance=elem, ar=ar)
-            elem.before_ui_save(ar)
+            elem.before_ui_save(ar, watcher)
 
             kw2save = {}
             if is_new:
@@ -1429,7 +1429,8 @@ class ActionRequest(ActorRequest):
         self.rqdata = rqdata
         self.bound_action = action or actor.default_action
         BaseRequest.__init__(self, **kw)
-        self.ah = actor.get_request_handle(self)
+        if not actor.is_abstract():
+            self.ah = actor.get_request_handle(self)
 
     def __str__(self):
         return "{0} {1}".format(self.__class__.__name__, self.bound_action)
@@ -1456,10 +1457,8 @@ class ActionRequest(ActorRequest):
 
         request = self.request
 
-        # Must have master instance already
         if self.actor.parameters is not None:
             pv = self.actor.param_defaults(self)
-
             for k in pv.keys():
                 if k not in self.actor.parameters:
                     raise Exception(
@@ -1485,7 +1484,13 @@ class ActionRequest(ActorRequest):
                 if self.actor.master_key in pv:
                     pv[self.actor.master_key] = self.master_instance
             if param_values is None:
-                if request is not None:
+                if self.actor.params_layout is None:
+                    pass # 20200825 e.g. users.Users
+                    # raise Exception(
+                    #     "{} has parameters ({}) but no params_layout. {}".format(
+                    #     self.actor, self.actor.parameters, self.actor._setup_done))
+
+                elif request is not None:
                     # call get_layout_handle to make sure that
                     # params_store has been created:
                     self.actor.params_layout.get_layout_handle(
@@ -1511,6 +1516,9 @@ class ActionRequest(ActorRequest):
             self.param_values = AttrDict(**pv)
             # self.actor.check_params(self.param_values)
 
+        if self.bound_action is None:
+            return  # 20200825 e.g. a request on an abstract table
+
         action = self.bound_action.action
         if action.parameters is not None:
             if len(self.selected_rows) == 1:
