@@ -12,7 +12,7 @@ import datetime
 
 from django.db import models
 from django.db.models import Q
-from django.db.models.fields import FieldDoesNotExist
+from django.core.exceptions import FieldDoesNotExist
 from django.utils.functional import lazy
 from importlib import import_module
 from django.utils.translation import ugettext as _
@@ -43,8 +43,12 @@ def comma():
 def qs2summary(ar, objects, separator=comma, max_items=5, **kw):
     """Render a collection of objects as a single paragraph.
 
+    :param separator: separator to use between objects. This must be a callable.
     :param max_items: don't include more than the specified number of items.
 
+    The separator must be a callable because with etree you may not reuse a same
+    element instance several times.
+
     """
     elems = []
     n = 0
@@ -56,7 +60,7 @@ def qs2summary(ar, objects, separator=comma, max_items=5, **kw):
         if n >= max_items:
             elems += [separator(), '...']
             break
-    return E.p(*elems)
+    return elems
 
 
 def getrqdata(request):
@@ -855,3 +859,25 @@ def db2param(spec):
 
     """
     return dbfield2params_field(resolve_field(spec))
+
+
+def traverse_ddh_fklist(model, ignore_mti_parents=True):
+    """When an application uses MTI (e.g. with a Participant model being a
+    specialization of Person, which itself a specialization of
+    Partner) and we merge two Participants, then we must of course
+    also merge their invoices and bank statement items (linked via a
+    FK to Partner) and their contact roles (linked via a FK to
+    Person).
+
+    """
+    for base in model.mro():
+        ddh = getattr(base, '_lino_ddh', None)
+        if ddh is not None:
+            for (m, fk) in ddh.fklist:
+                if ignore_mti_parents and isinstance(fk, models.OneToOneField):
+                    pass
+                    # logger.info("20160621 ignore OneToOneField %s", fk)
+                else:
+                    # logger.info("20160621 yield %s (%s)",
+                    #             fk, fk.__class__)
+                    yield (m, fk)
