@@ -1,7 +1,7 @@
-# Copyright 2014-2015 Josef Kejzlar, Rumma & Ko Ltd
+# Copyright 2014-2020 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-"""This app installs a button to "export" any table to excel xls format.
+"""This plugin installs a button to export any table to excel xls format.
 
 To use it, simply add the following line to your
 :meth:`lino.core.site.Site.get_installed_apps`::
@@ -10,12 +10,8 @@ To use it, simply add the following line to your
 
 """
 
-from lino import ad
-
-from django.utils.translation import ugettext_lazy as _
-
+from lino import ad, _
 
 class Plugin(ad.Plugin):
     "See :doc:`/dev/plugins`."
     verbose_name = _("Export to Excel xls format")
-
