@@ -133,6 +133,9 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
     def is_editable_by_all(self):
         return False
 
+    def has_required_roles(self, *args):
+        return self.user_type.has_required_roles(*args)
+
     def get_row_permission(self, ar, state, ba):
         # import pdb ; pdb.set_trace()
         if not ba.action.readonly:
@@ -267,7 +270,7 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
 
     def get_authorities(self):
 
-        if self.user_type.has_required_roles([Supervisor]):
+        if self.has_required_roles([Supervisor]):
             users = settings.SITE.user_model.objects.exclude(
                     user_type='').exclude(id=self.id)
         else:
