@@ -15,7 +15,7 @@ import sys
 
 SETUP_INFO = dict(
     name='lino',
-    version='20.7.8',
+    version='20.12.0',
     description="A framework for writing desktop-like web applications "
                 "using Django and ExtJS or React",
     license='BSD-2-Clause',
@@ -42,7 +42,8 @@ install_requires = [
     'html2text',
     'schedule']
 
-# install_requires.append('docutils')
+install_requires.append('Sphinx')  # lino.utils.restify
+install_requires.append('docutils')  # lino.modlib.memo.mixins
 install_requires.append('beautifulsoup4')  # lino.modlib.memo.mixins
 # install_requires.append('reportlab')
 install_requires.append('weasyprint')
