@@ -82,7 +82,7 @@ from sphinx.util import logging ; logger = logging.getLogger(__name__)
 
 from importlib import import_module
 
-from unipath import Path
+from pathlib import Path
 from lino.core.utils import simplify_name
 
 useless_starts = set(['lino.core'])
@@ -93,7 +93,6 @@ useless_endings = set(['.My', '.ByUser'])
 
 HEADER = """# -*- coding: UTF-8 -*-
 # generated by lino.sphinxcontrib.help_text_builder
-from __future__ import unicode_literals
 from django.utils.translation import ugettext_lazy as _
 """
 
@@ -106,6 +105,7 @@ def node2html(node):
 class HelpTextExtractor(object):
 
     def initialize(self, app):
+        # print("20200815 HelpTextExtractor.initialize", app)
         self.name2dict = dict()
         self.name2file = dict()
         # we must write our files only when all documents have been
@@ -116,16 +116,17 @@ class HelpTextExtractor(object):
         # print(20160725, targets)
         for root, modname in targets.items():
             mod = import_module(modname)
-            htf = Path(mod.__file__).parent.child('help_texts.py')
+            htf = Path(mod.__file__).parent / 'help_texts.py'
             # if not htf.exists():
             #     raise Exception("No such file: {}".format(htf))
-            self.name2file[root] = htf
+            self.name2file[root] = str(htf)
             self.name2dict[root] = OrderedDict()
 
         print("Collecting help texts for {}".format(
             ' '.join(self.name2file.values())))
 
     def extract_help_texts(self, app, doctree):
+        # print("20200815 HelpTextExtractor.extract_help_texts")
         # if docname != 'api/lino_xl.lib.invoicing.models':
         #     return
         # print(doctree)
@@ -141,6 +142,8 @@ class HelpTextExtractor(object):
                     self.store_content(node)
                 elif node['objtype'] == 'method':
                     self.store_content(node)
+            # else:
+            #     print("20200815 domain is not py", node['domain'])
         # for node in doctree.traverse(nodes.field):
         #     self.fields.add(node.__class__)
         self.docs_processed += 1
@@ -160,31 +163,32 @@ class HelpTextExtractor(object):
                     self.docs_processed,
                     len(app.env.found_docs)))
             return
+        # print("20200815 HelpTextExtractor.write_help_texts_files", len(self.name2file))
         for k, fn in self.name2file.items():
             texts = self.name2dict.get(k, None)
             if not texts:
                 logger.info("No help texts for {}".format(k))
                 continue
             # fn = os.path.join(self.outdir, 'help_texts.py')
-            print("Writing {} help texts for {} to {}".format(
+            logger.info("Writing {} help texts for {} to {}".format(
                 len(texts), k, fn))
 
-            fd = open(fn, "w")
+            with open(fn, "w") as fd:
 
-            def writeln(s):
-                # if six.PY2:
-                #     s = s.encode('utf-8')
-                fd.write(s)
-                fd.write("\n")
+                def writeln(s):
+                    # if six.PY2:
+                    #     s = s.encode('utf-8')
+                    fd.write(s)
+                    fd.write("\n")
 
-            writeln(HEADER)
-            writeln("help_texts = {")
-            for k, v in texts.items():
-                writeln('''    '{}' : _("""{}"""),'''.format(k, v))
-            writeln("}")
-            fd.close()
+                writeln(HEADER)
+                writeln("help_texts = {")
+                for k, v in texts.items():
+                    writeln('''    '{}' : _("""{}"""),'''.format(k, v))
+                writeln("}")
 
     def store_content(self, node):
+        # logger.info("20200815 store_content")
         sig = []
         content = []
         for c in node.children:
@@ -216,7 +220,11 @@ class HelpTextExtractor(object):
             content += " "
             # msg = '{} : First paragraph of content may not end with \'"\'.'
             # self.warn(msg.format(sig['names'][0]))
-        for name in sig['names']:
+        # if len(sig['names']) == 0:
+        #     logger.info("20200815 store_content sig is {}".format(sig))
+        # else:
+        #     logger.info("20200815 store_content sig['names'] is {}".format(sig['names']))
+        for name in sig['ids']:
             self.sig2dict(name, content)
 
     def sig2dict(self, name, value):
