@@ -1,18 +1,30 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2014 Luc Saffre
+# Copyright 2012-2015 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 
-u"""
+u"""A collection of tools for generating fictive people and addresses.
 
 This module is used by
 
-- :mod:`garble <lino.modlib.contacts.management.commands.garble_persons>`
+- :mod:`lino_xl.lib.contacts.fixtures.demo`
+
+- :mod:`lino_xl.lib.addresses.fixtures.demo2`
+
+- :mod:`garble_persons
+  <lino_xl.lib.contacts.management.commands.garble_persons>`
+
 - :mod:`garble <lino_welfare.modlib.pcsw.management.commands.garble>`
 
-Usage examples see
+- :xfile:`garble_tx25.py` in
+  :mod:`lino_welfare.modlib.cbss.fixtures.cbss_demo`
+
+.. autosummary::
+   :toctree:
+
+   bel
+   est
+   rus
 
-- :mod:`lino.utils.demonames.bel`
-- :mod:`lino.utils.demonames.est`
 
 
 """
