@@ -6,9 +6,6 @@
 
 """
 
-from __future__ import unicode_literals
-from builtins import object
-
 from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
